ServiceUnavailableException class final

Exception thrown when the server returns a "503 Service Unavailable" response.

Inheritance

Constructors

ServiceUnavailableException(String message, {Status? status})

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
A message describing the cause of the exception.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status → Status?
The status message returned by the server.
finalinherited
statusCode int
The HTTP status code that the server returned (e.g. 404).
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited