FakeLocations class base
Testing fake for Locations.
- Implemented types
Constructors
-
FakeLocations({Future<
ListLocationsResponse> listLocations(ListLocationsRequest request)?, Future<Location> getLocation(GetLocationRequest request)?})
Properties
Methods
-
close(
) → void -
Closes the client and cleans up any resources associated with it.
override
-
getLocation(
GetLocationRequest request) → Future< Location> -
Gets information about a location.
override
-
listLocations(
ListLocationsRequest request) → Future< ListLocationsResponse> -
Lists information about the supported locations for this service.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited