listLocations method

  1. @override
Future<ListLocationsResponse> listLocations(
  1. ListLocationsRequest request
)
override

Lists information about the supported locations for this service.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<ListLocationsResponse> listLocations(
  ListLocationsRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_listLocations case final listLocations?) {
    return listLocations(request);
  }
  throw UnsupportedError('listLocations');
}