location library
The Google Cloud client for the Cloud Metadata API.
This API provides static metadata about Google Cloud Platform. Currently, it only provides basic information about Google Cloud locations, such as zones, regions, and countries.
Classes
- GetLocationRequest
-
The request message for
Locations.GetLocation. - ListLocationsRequest
-
The request message for
Locations.ListLocations. - ListLocationsResponse
-
The response message for
Locations.ListLocations. - Location
- A resource that represents Google Cloud Platform location.
- Locations
-
An abstract interface that provides location-related information for
a service. Service-specific metadata is provided through the
Location.metadatafield.
Exceptions / Errors
- BadGatewayException
- Exception thrown when the server returns a "502 Bad Gateway" response.
- BadRequestException
- Exception thrown when the server returns a "400 Bad Request" response.
- CancelledException
- Exception thrown when the server returns a "499 Cancelled" response.
- ConfigurationException
- Exception thrown when a method is called without correct configuration.
- ConflictException
- Exception thrown when the server returns a "409 Conflict" response.
- ForbiddenException
- Exception thrown when the server returns a "403 Forbidden" response.
- GatewayTimeoutException
- Exception thrown when the server returns a "504 Gateway Timeout" response.
- InternalServerErrorException
- Exception thrown when the server returns a "500 Internal Server Error" response.
- LengthRequiredException
- Exception thrown when the server returns a "411 Length Required" response.
- MethodNotAllowedException
- Exception thrown when the server returns a "405 Method Not Allowed" response.
- NotFoundException
- Exception thrown when the server returns a "404 Not Found" response.
- NotImplementedException
- Exception thrown when the server returns a "501 Not Implemented" response.
- NotModifiedException
- Exception thrown when the server returns a "304 Not Modified" response.
- PreconditionFailedException
- Exception thrown when the server returns a "412 Precondition Failed" response.
- RequestRangeNotSatisfiableException
- Exception thrown when the server returns a "416 Request Range Not Satisfiable" response.
- RequestTimeoutException
- Exception thrown when the server returns a "408 Request Timeout" response.
- ServiceException
- Exception thrown when an API call fails.
- Exception thrown when the server returns a "503 Service Unavailable" response.
- TooManyRequestsException
- Exception thrown when the server returns a "429 Too Many Requests" response.
- Exception thrown when the server returns a "401 Unauthorized" response.